# Module for implement UDP server

import socketserver


class server_handler(socketserver.BaseRequestHandler):
    """ The request handler class for the server """

    def handle(self):
        self._data = self.request[0].strip()
        self._socket = self.request[1]
        print("{} wrote: ".format(self.client_address[0]))
        print(self._data.decode("utf-8"))
        self._socket.sendto(self._data, self.client_address)
        return


def main():
    host, port = "localhost", 9999

    with socketserver.UDPServer((host, port), server_handler) as server:
        server.handle_request()


if __name__ == "__main__":
    main()



# first api implementation

import urllib.request


def requesting_info(url, num_char=100):
    """ Method to fetch info from an url

    :param url: string obj containing the URL to be read
    :param num_char: int obj containing info of the number of characters to be read
    :return: string obj contains data to be returned
    """
    try:
        file = urllib.request.urlopen(url)
    except ValueError:
        return "URL NOT FOUND!!"

    response = file.read(num_char).decode('utf-8')
    return response


if __name__ == '__main__':
    url = "https://sixty-north.com/c/t.txt"
    print(requesting_info(url))



# This module is used to generate ip addresses of a given range

import ipaddress


def check(ip_value, network):
    """ Method to verify IP address network"""
    if network:
        grp = ipaddress.IPv4Network
    else:
        grp = ipaddress.IPv6Network
    try:
        ip_value = grp(ip_value)
    except (ipaddress.AddressValueError, ValueError, ipaddress.NetmaskValueError):
        return None

    return ip_value


def generate_ip(ip_value):
    """ Methods generate an itr for a range of ip address"""
    ip_value = check(ip_value,True)
    if ip_value is None:
        ip_value = check(ip_value,False)

    if ip_value is None:
        print("Incorrect Network IP entered")
        return None

    data = []
    for ipaddr in ip_value:
        data.append(ipaddr)

    return data


if __name__ == '__main__':
    for ip_address in generate_ip('192.168.0.0/24'):
        print(ip_address)


import socket
import sys


def main(host, port):
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    with sock:
        sock.bind((host, port))
        sock.listen(1)
        conn, addr = sock.accept()
        with conn:
            print('Connected by', addr)
            conn.sendall(b"Enter username")
            username = conn.recv(1024)
            conn.sendall(b"Enter password")
            password = conn.recv(1024)
            if username == b"Rishabh" and password == b"Pallod":
                conn.sendall(b"Login successful")
            else:
                conn.sendall(b'Incorrect user details')
    return


if __name__ == "__main__":
    main('localhost', 50007)



# This module is used to remotely execute server functions

import xmlrpc.client


def remote_function(server_url, a, b=2):
    """ Method to remotely access raise power function on the server
        :arg: server_url : Takes the host and port details of server
        :arg: a, b : int objs as input for floor_divide method

        :returns: int obj on success and None on failure
    """
    server_proxy = xmlrpc.client.ServerProxy(server_url)
    try:
        return server_proxy.floor_divide(a, b)
    except xmlrpc.client.Fault as err:
        print("A fault occurred")
        print("Fault code: %d" % err.faultCode)
        print("Fault string: %s" % err.faultString)
        return None


if __name__ == '__main__':
    print(remote_function("http://localhost:8000/", 5, 3))
